@@ -1,41 +1,35 @@
-""" 
-    Twisted connection type. 
+"""
+    Twisted connection type.
 
     See COPYING for license information
 """
 from zope import interface
 
 from object_storage.transport import requote_path
-from object_storage.errors import ResponseError, NotFound
+from object_storage.errors import NotFound
 from object_storage.transport import Response, BaseAuthenticatedConnection, BaseAuthentication
-from object_storage import consts
+from object_storage import errors
 
 from twisted.internet import reactor
-from twisted.internet.defer import Deferred, succeed
+from twisted.internet.defer import Deferred
 from twisted.internet.protocol import Protocol
 from twisted.internet.ssl import ClientContextFactory
 from twisted.web.client import Agent
 from twisted.web.http_headers import Headers
-from twisted.web.client import FileBodyProducer
 from twisted.web.iweb import IBodyProducer, UNKNOWN_LENGTH
 
-import urlparse, urllib
+import urlparse
+import urllib
 
-import json
+from object_storage.utils import json
 
-""":param method: method for the new :class:`Request` object.
-    :param url: URL for the new :class:`Request` object.
-    :param params: (optional) Dictionary or bytes to be sent in the query string for the :class:`Request`.
-    :param data: (optional) Dictionary or bytes to send in the body of the :class:`Request`.
-    :param headers: (optional) Dictionary of HTTP Headers to send with the :class:`Request`.
-"""
 
 def complete_request(resp, callback=None, load_body=True):
     r = Response()
     r.status_code = resp.code
     r.version = resp.version
     r.phrase = resp.phrase
-    headers = {}
+
     for k, v in resp.headers.getAllRawHeaders():
         r.headers[k.lower()] = v.pop()
 
@@ -60,13 +54,15 @@ def complete_request(resp, callback=None, load_body=True):
     finished.addCallback(build_response)
     return finished
 
+
 def print_error(failure):
-    from twisted.web import _newclient 
+    from twisted.web import _newclient
     if failure.check(_newclient.RequestGenerationFailed):
         for f in failure.value.reasons:
             print f.getTraceback()
     return failure
 
+
 class AuthenticatedConnection(BaseAuthenticatedConnection):
     def __init__(self, auth, **kwargs):
         self.token = None
@@ -83,22 +79,23 @@ class AuthenticatedConnection(BaseAuthenticatedConnection):
         headers.update(self.get_headers())
         return make_request(method, url=url, headers=headers, *args, **kwargs)
 
+
 def make_request(method, url=None, headers=None, *args, **kwargs):
     """ Makes a request """
-    headers = Headers(dict([ (k, [v]) for k, v in headers.items() ]))
-        
+    headers = Headers(dict([(k, [v]) for k, v in headers.items()]))
+
     formatter = None
     if 'formatter' in kwargs:
         formatter = kwargs.get('formatter')
         del kwargs['formatter']
-        
+
     if not formatter:
         def _nothing(result):
             return result
         formatter = _nothing
 
     params = kwargs.get('params', None)
-    
+
     if params:
         params = urllib.urlencode(params)
 
@@ -114,15 +111,16 @@ def make_request(method, url=None, headers=None, *args, **kwargs):
         url,
         headers,
         body)
-        
-    load_body=True
+
+    load_body = True
     if method.upper() in ['HEAD', 'DELETE']:
-        load_body=False
+        load_body = False
 
     d.addCallback(complete_request, formatter, load_body=load_body)
     d.addErrback(print_error)
     return d
 
+
 def _full_url(url, _params={}):
     """Build the actual URL to use."""
 
@@ -139,7 +137,7 @@ def _full_url(url, _params={}):
 
     path = requote_path(path)
 
-    url = str(urlparse.urlunparse([ scheme, netloc, path, params, query, fragment ]))
+    url = str(urlparse.urlunparse([scheme, netloc, path, params, query, fragment]))
 
     if _params:
         if urlparse.urlparse(url).query:
@@ -149,6 +147,7 @@ def _full_url(url, _params={}):
     else:
         return url
 
+
 class Authentication(BaseAuthentication):
     """
         Authentication class.
@@ -193,10 +192,12 @@ class Authentication(BaseAuthentication):
         d.addCallback(self._authenticate)
         return d
 
+
 class WebClientContextFactory(ClientContextFactory):
     def getContext(self, hostname, port):
         return ClientContextFactory.getContext(self)
 
+
 class FullBodyReader(Protocol):
     def __init__(self, finished):
         self.finished = finished
@@ -208,8 +209,9 @@ class FullBodyReader(Protocol):
     def connectionLost(self, reason):
         self.finished.callback(self.body)
 
+
 class ChunkedConnection:
-    """ 
+    """
         Chunked Connection class.
         setup() will initiate a HTTP connection.
         send_chunk() will send more data.
@@ -225,7 +227,7 @@ class ChunkedConnection:
         self.body = ChunkedStreamProducer(self.started, self.size)
 
     def setup(self, size=None):
-        """ 
+        """
             Sets up the connection. Will optionally accept a size or
             else will use a chunked Transfer-Encoding.
         """
@@ -237,7 +239,7 @@ class ChunkedConnection:
         req = self.conn.make_request('PUT', self.url, headers=self.headers, data=self.body)
         self.req = req
         print "ChunkedTwistedConnection: STARTED REQUEST"
-   
+
     def send_chunk(self, chunk):
         """ Sends a chunk of data. """
         print "ChunkedTwistedConnection: send chunk"
@@ -247,6 +249,7 @@ class ChunkedConnection:
         """ Finished the request out and receives a response. """
         self.body.finish()
 
+
 class ChunkedStreamProducer(object):
     interface.implements(IBodyProducer)
 
